@@ -1,10 +1,10 @@
-__version__ = "0.0.4"
+__version__ = "0.0.5"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
 __git_branch__ = '(Not currently on any branch)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '8a7c4c40d518edde50d02db5b4f8b5669852a7aa'
-__git_head_subject__ = 'Finished release v0.0.4.'
+__git_head_hash__ = 'b536a10176ae11b2f4bc9930c15349eb6bd4bda0'
+__git_head_subject__ = 'empty commit after version v0.0.4'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
